@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Base.pm 4200 2007-10-25T14:51:15.908897Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Base.pm 31143 2007-11-27T06:57:15.188797Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -6,7 +6,6 @@
 package Gungho::Base;
 use strict;
 use warnings;
-use Gungho::Base::Class;
 use base qw(Gungho::Base::Class Class::Accessor::Fast);
 
 __PACKAGE__->mk_accessors($_) for qw(config);
@@ -18,6 +17,18 @@ sub new
     return $self;
 }
 
+sub mk_virtual_methods
+{
+    my $class = shift;
+    foreach my $method (@_) {
+        my $slot = "${class}::${method}";
+        {
+            no strict 'refs';
+            *{$slot} = sub { die(ref($_[0]) . "::${method} is not overridden") };
+        }
+    }
+}
+
 1;
 
 __END__
@@ -48,4 +59,10 @@ Sets up the object. Use it like this in your object:
      $self->next::method(@_);
   }
 
+=head2 mk_virtual_methods
+
+Creates virtual methods (methods that must be overridden).
+These methods will C<die()> unless you provide an implementation in your
+subclass
+
 =cut
