@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/RobotsMETA.pm 3532 2007-10-17T12:49:55.724702Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/RobotsMETA.pm 31095 2007-11-26T00:05:40.329716Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -22,13 +22,13 @@ sub handle_response
 {
     my ($self, $req, $res) = @_;
 
-    if ($res->content_type =~ m{^text/html}i) {
+    if ($res->is_success && $res->content_type =~ m{^text/html}i) {
         eval {
             my $rules = $self->robots_meta->parse_rules( $res->content );
             $res->notes( robots_meta => $rules );
         };
         if ($@) {
-            $self->log->debug("Failed to parse " . $res->uri . " for robots META information: $@");
+            $self->log->debug("Failed to parse " . $res->request->uri . " for robots META information: $@");
         }
     }
     $self->next::method($req, $res);
@@ -56,6 +56,14 @@ directies embedded in the document.
 
 =head2 setup
 
+Initializes the component.
+
 =head2 handle_response
 
+Overrides Gungho::Component::Core::handle_response()
+
+=head1 SEE ALSO 
+
+L<HTML::RobotsMETA|HTML::RobotsMETA>
+
 =cut
