@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 31130 2007-11-27T01:45:05.109813Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 39017 2008-01-16T16:05:45.674472Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -113,7 +113,7 @@ sub run
     # PoCo::Client::HTTP 0.82, PoCo::Client::HTTP tended to get filled up
     # pretty quickcly)
     $self->clients( [] );
-    my $spawn = $client_config->{spawn} || 2;
+    my $spawn = delete $client_config->{Spawn} || 2;
     if ($spawn < 1) { $spawn = 2 }
     for my $i ( 1 .. $spawn ) {
         my $alias = join('-', &UserAgentAlias, $i);
@@ -139,8 +139,9 @@ sub run
             }
         ]
     );
-    
-    POE::Kernel->run();
+
+    POE::Kernel->run() if
+        ! exists $config{ kernel_start } || $config{ kernel_start };
 }
 
 sub stop
@@ -367,6 +368,14 @@ Or in perl,
     }
   }
 
+=head2 kernel_start
+
+If you're embedding Gungho into another POE application, you probably don't
+want Gungho to call POE::Kernel->run(). This option can control that behavior.
+
+If you don't want to start the kernel, then specify 0 for this option.
+The default is 1.
+
 =head2 client.loop_delay
 
 C<loop_delay> specifies the number of seconds to wait until calling C<dispatch>
